nicfit\.shell package
=====================

.. automodule:: nicfit.shell
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

nicfit\.shell\.command module
-----------------------------

.. automodule:: nicfit.shell.command
    :members:
    :undoc-members:
    :show-inheritance:

nicfit\.shell\.completion module
--------------------------------

.. automodule:: nicfit.shell.completion
    :members:
    :undoc-members:
    :show-inheritance:

nicfit\.shell\.output module
----------------------------

.. automodule:: nicfit.shell.output
    :members:
    :undoc-members:
    :show-inheritance:


